==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_fileinspector.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_fileinspector.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("FC_LAN_1", "File Inspector");
define("FC_LAN_2", "Scan Options");
define("FC_LAN_3", "Show");
define("FC_LAN_4", "All");
define("FC_LAN_5", "Core Files");
define("FC_LAN_6", "Integrity Fail Only");
define("FC_LAN_7", "Non Core Files");
define("FC_LAN_8", "Check Integrity Of Core Files");
define("FC_LAN_9", "On");
define("FC_LAN_10", "Off");
define("FC_LAN_11", "Scan Now");
define("FC_LAN_12", "None");
define("FC_LAN_13", "Missing Core Files");
define("FC_LAN_14", "Display results as");
define("FC_LAN_15", "Directory Tree");
define("FC_LAN_16", "List");
define("FC_LAN_17", "String Matching");
define("FC_LAN_18", "Regular expression");
define("FC_LAN_19", "Show line numbers");
define("FC_LAN_20", "Show matched lines");
define("FC_LAN_21", "Old Core Files");

define("FR_LAN_1", "Scanning");
define("FR_LAN_2", "Scan Results");
define("FR_LAN_3", "Overview");
define("FR_LAN_4", "Core files");
define("FR_LAN_5", "Non core files");
define("FR_LAN_6", "Total files");
define("FR_LAN_7", "Integrity Check");
define("FR_LAN_8", "Core files passed");
define("FR_LAN_9", "Core files failed");
define("FR_LAN_10", "Possible reasons for files to fail");
define("FR_LAN_11", "The file is corrupted");
define("FR_LAN_12", "This could be for a number of reasons such as the file being corrupted in the zip, got corrupted during 
extraction or got corrupted during file upload via FTP. You should try re-uploading the file to your server 
and re-run the scan to see if this resolves the error.");
define("FR_LAN_13", "The file is out of date");
define("FR_LAN_14", "If the file is from an older release of e107 to the version you are 
running then it will fail the integrity check. Make sure you have uploaded the newest version of this file.");
define("FR_LAN_15", "The file has been edited");
define("FR_LAN_16", "If you have edited this file in any way it will not pass the integrity check. If you
intentionally edited this file then you need not worry and can ignore this integrity check fail. If however
the file was edited by someone else without authorisation you may want to re-upload the proper version of
this file from the e107 zip.");
define("FR_LAN_17", "If you are a CVS user");
define("FR_LAN_18", "If you run checkouts of the e107 CVS on your site instead of the official e107 stable 
releases, then you will discover files have failed integrity check because they have been edited by a dev 
after the latest core image snapshot was created.");
define("FR_LAN_19", "files failed");
define("FR_LAN_20", "All files passed");
define("FR_LAN_21", "none");
define("FR_LAN_22", "Missing core files");
define("FR_LAN_23", "No matches found.");
define("FR_LAN_24", "Old core files");
define("FR_LAN_25", "Integrity incalculable");

define("FR_LAN_26", "Warning! Known Insecurity Detected!");
define("FR_LAN_27", "There are files on your server that are known to be exploitable and must be removed immediately.");
define("FR_LAN_28", "Known insecure files");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_fileinspector.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_fileinspector.php $
|     $Revision: 11717 $
|     $Id: lan_fileinspector.php 11717 2010-08-30 07:36:37Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/

define("FC_LAN_1", "File Inspector");
define("FC_LAN_2", "Scan Options");
define("FC_LAN_3", "Show");
define("FC_LAN_4", "All");
define("FC_LAN_5", "Core Files");
define("FC_LAN_6", "Integrity Fail Only");
define("FC_LAN_7", "Non Core Files");
define("FC_LAN_8", "Check Integrity Of Core Files");
define("FC_LAN_9", "On");
define("FC_LAN_10", "Off");
define("FC_LAN_11", "Scan Now");
define("FC_LAN_12", "None");
define("FC_LAN_13", "Missing Core Files");
define("FC_LAN_14", "Display results as");
define("FC_LAN_15", "Directory Tree");
define("FC_LAN_16", "List");
define("FC_LAN_17", "String Matching");
define("FC_LAN_18", "Regular expression");
define("FC_LAN_19", "Show line numbers");
define("FC_LAN_20", "Show matched lines");
define("FC_LAN_21", "Old Core Files");

define("FR_LAN_1", "Scanning");
define("FR_LAN_2", "Scan Results");
define("FR_LAN_3", "Overview");
define("FR_LAN_4", "Core files");
define("FR_LAN_5", "Non core files");
define("FR_LAN_6", "Total files");
define("FR_LAN_7", "Integrity Check");
define("FR_LAN_8", "Core files passed");
define("FR_LAN_9", "Core files failed");
define("FR_LAN_10", "Possible reasons for files to fail");
define("FR_LAN_11", "The file is corrupted");
define("FR_LAN_12", "This could be for a number of reasons such as the file being corrupted in the zip, got corrupted during 
extraction or got corrupted during file upload via FTP. You should try re-uploading the file to your server 
and re-run the scan to see if this resolves the error.");
define("FR_LAN_13", "The file is out of date");
define("FR_LAN_14", "If the file is from an older release of e107 to the version you are 
running then it will fail the integrity check. Make sure you have uploaded the newest version of this file.");
define("FR_LAN_15", "The file has been edited");
define("FR_LAN_16", "If you have edited this file in any way it will not pass the integrity check. If you
intentionally edited this file then you need not worry and can ignore this integrity check fail. If however
the file was edited by someone else without authorisation you may want to re-upload the proper version of
this file from the e107 zip.");
define("FR_LAN_17", "If you are an SVN user");
define("FR_LAN_18", "If you run checkouts of the e107 SVN on your site instead of the official e107 stable 
releases, then you will discover files have failed integrity check because they have been edited by a dev 
after the latest core image snapshot was created.");
define("FR_LAN_19", "files failed");
define("FR_LAN_20", "All files passed");
define("FR_LAN_21", "none");
define("FR_LAN_22", "Missing core files");
define("FR_LAN_23", "No matches found.");
define("FR_LAN_24", "Old core files");
define("FR_LAN_25", "Integrity incalculable");

define("FR_LAN_26", "Warning! Known Insecurity Detected!");
define("FR_LAN_27", "There are files on your server that are known to be exploitable and must be removed immediately.");
define("FR_LAN_28", "Known insecure files");

?>
